@@ -1,5 +1,5 @@
-test_that("pop uf general is consistent", {
-  res <- uf_pop() %>%
+test_that("datasus pop uf general is consistent", {
+  res <- uf_pop_age(source = "datasus") %>%
     dplyr::group_by(year, age_group) %>%
     dplyr::summarise(freq = sum(pop, na.rm = TRUE)) %>%
     dplyr::ungroup() %>%
@@ -10,8 +10,8 @@ test_that("pop uf general is consistent", {
   expect_equal(nrow(res), 0)
 })
 
-test_that("pop uf male is consistent", {
-  res <- uf_male_pop %>%
+test_that("ufrn pop uf general is consistent", {
+  res <- uf_pop_age(source = "ufrn") %>%
     dplyr::group_by(year, age_group) %>%
     dplyr::summarise(freq = sum(pop, na.rm = TRUE)) %>%
     dplyr::ungroup() %>%
@@ -22,15 +22,5 @@ test_that("pop uf male is consistent", {
   expect_equal(nrow(res), 0)
 })
 
-test_that("pop uf female is consistent", {
-  res <- uf_female_pop %>%
-    dplyr::group_by(year, age_group) %>%
-    dplyr::summarise(freq = sum(pop, na.rm = TRUE)) %>%
-    dplyr::ungroup() %>%
-    dplyr::group_by(freq) %>%
-    dplyr::summarise(count = dplyr::n()) %>%
-    dplyr::filter(count > 1)
 
-  expect_equal(nrow(res), 0)
-})
 
